@@ -32,6 +32,7 @@
     ObjectPrototypeHasOwnProperty,
     ObjectEntries,
     RegExpPrototypeTest,
+    SafeArrayIterator,
     Symbol,
     SymbolFor,
     SymbolIterator,
@@ -230,7 +231,10 @@
       }
 
       return ArrayPrototypeSort(
-        [...ObjectEntries(headers), ...cookies],
+        [
+          ...new SafeArrayIterator(ObjectEntries(headers)),
+          ...new SafeArrayIterator(cookies),
+        ],
         (a, b) => {
           const akey = a[0];
           const bkey = b[0];
@@ -263,7 +267,7 @@
      * @param {string} value
      */
     append(name, value) {
-      webidl.assertBranded(this, Headers);
+      webidl.assertBranded(this, HeadersPrototype);
       const prefix = "Failed to execute 'append' on 'Headers'";
       webidl.requiredArguments(arguments.length, 2, { prefix });
       name = webidl.converters["ByteString"](name, {
@@ -354,7 +358,7 @@
      * @param {string} value
      */
     set(name, value) {
-      webidl.assertBranded(this, Headers);
+      webidl.assertBranded(this, HeadersPrototype);
       const prefix = "Failed to execute 'set' on 'Headers'";
       webidl.requiredArguments(arguments.length, 2, { prefix });
       name = webidl.converters["ByteString"](name, {
@@ -411,6 +415,7 @@
   webidl.mixinPairIterable("Headers", Headers, _iterableHeaders, 0, 1);
 
   webidl.configurePrototype(Headers);
+  const HeadersPrototype = Headers.prototype;
 
   webidl.converters["HeadersInit"] = (V, opts) => {
     // Union for (sequence<sequence<ByteString>> or record<ByteString, ByteString>)
@@ -428,7 +433,7 @@
   };
   webidl.converters["Headers"] = webidl.createInterfaceConverter(
     "Headers",
-    Headers,
+    Headers.prototype,
   );
 
   /**
